@@ -1,4 +1,4 @@
-# Copyright 2021 UW-IT, University of Washington
+# Copyright 2022 UW-IT, University of Washington
 # SPDX-License-Identifier: Apache-2.0
 
 """
@@ -137,7 +137,8 @@ def update_registration_block(registration_block, actas_netid=None):
     Returns a uw_sws.models.RegistrationBlock object
     """
     url = registration_block_url.format(registration_block.uwregid)
-    headers = {"If-Match": "*"}
+    headers = {}
+
     if actas_netid:
         headers["X-UW-Act-as"] = actas_netid
 
