@@ -1,4 +1,4 @@
-# Copyright 2021 UW-IT, University of Washington
+# Copyright 2022 UW-IT, University of Washington
 # SPDX-License-Identifier: Apache-2.0
 
 from unittest import TestCase
@@ -92,7 +92,7 @@ class SWSTestRegistrations(TestCase):
              'is_withdrew': False,
              'meta_data': 'RegistrationSourceLocation=SDB;',
              'repeat_course': False,
-             'repository_timestamp': '2016-01-05 14:45:15',
+             'repository_timestamp': '2016-01-05T14:45:15',
              'request_date': '2015-11-18',
              'request_status': 'DROPPED FROM CLASS',
              'start_date': None})
@@ -322,5 +322,5 @@ class SWSTestRegistrationBlock(TestCase):
         mock_put.assert_called_with((
             '/student/v5/person/9136CCB8F66711D5BE060004AC494FFE/'
             'registrationblock.json'),
-            {'X-UW-Act-as': 'bill', 'If-Match': '*'},
+            {'X-UW-Act-as': 'bill'},
             {'Covid19StatusCode': 3, 'Covid19StatusDate': '20211003'})
